import UploadImg from "@/components/uploadImg";
import { ArrowDownOutlined, ArrowUpOutlined } from "@ant-design/icons";
import { ProFormColumnsType } from "@ant-design/pro-components";
import styles from './index.less'
import { Select, Tooltip } from "antd";
import BookSelect from "@/components/bookSelect";
export function bannersConfig(): ProFormColumnsType<any>[] {
    return [
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                creatorButtonProps: {
                    creatorButtonText: "添加一个Banner",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动"><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动"><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            title: 'banner名称',
                            dataIndex: 'templateName',
                            colProps: {
                                span: 24
                            },
                            fieldProps: {
                                placeholder: '请输入banner名称'
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            }
                        },
                        {
                            title: 'banner类型',
                            dataIndex: 'bannerType',
                            valueType: 'radio',
                            valueEnum: { 0: { text: "小说" }, 1: { text: "活动" } },
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            }
                        },
                        {
                            valueType: 'dependency',
                            name: ['bannerType'],
                            columns: ({ bannerType }) => {
                                return [
                                    {
                                        dataIndex: "bookId",
                                        title: '小说',
                                        hideInForm: bannerType != 0,
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                        colProps: {
                                            span: 24
                                        },
                                        renderFormItem(schema, config, form, action) {
                                            return <BookSelect />
                                        },
                                    },
                                    {
                                        valueType: 'select',
                                        dataIndex: "activityPagePath",
                                        title: '活动页面',
                                        colProps: {
                                            span: 24
                                        },
                                        fieldProps: {
                                            style: { width: 'auto' },
                                            showSearch: true,
                                            placeholder: '请选择活动页面'
                                        },
                                        hideInForm: bannerType != 1,
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        }
                                    }
                                ]
                            }
                        },
                        {
                            title: 'banner图片',
                            dataIndex: 'bannerImage',
                            colProps: {
                                span: 24,
                            },
                            formItemProps: {
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem: () => {
                                return (
                                    <UploadImg
                                        size={{
                                            width: 690,
                                            height: 248,
                                            evalW: '!=',
                                            evalH: '!=',
                                            msg: '需要图片大小690*248',
                                        }}
                                        isEdit={true}
                                        type="image"
                                        isCropper
                                    />
                                );
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}
