import { useDrop } from "ahooks";
import { Col, Row, Space } from "antd";
import React, { useState, useImperativeHandle, forwardRef, useRef, useMemo } from "react";
import styles from './index.less'
import { Banners } from "../components/banners";
import { useModel } from "@umijs/max";

// 使用 forwardRef 以支持传递 ref
const DragItem = () => {
    const { state, dispatch } = useModel("appPageConifg")
    const [isHovering, setIsHovering] = useState(false);
    const dropRef = useRef(null);
    const list = useMemo(() => {
        return state.tabs === 0 ? state.manList : state.womanList
    }, [state])
    useDrop(dropRef, {
        // 接收到组件拖拽到手机内容内，添加进入数据
        onDom: (content: string, e) => {
            console.log(11111)
            let arr = content?.split('_')
            let appComponentId = arr[0]
            let componentType = arr[1]
            let pageUrl = arr[2]
            let newConfig = { appComponentId, componentType, pageUrl, configs: [] }
            let { tabs, manList, womanList } = state
            switch (componentType) {
                case "banners":
                    dispatch({
                        type: 'setAll', params: tabs === 0 ? {
                            manList: [...state.manList, newConfig]
                        } : {
                            womanList: [...state.womanList, newConfig]
                        }
                    })
                    break
                default:
                    break
            }
            console.log(`custom: ${content} dropped`);
        },
        onDragOver: (e) => {
            // console.log("拖拽中",e)
        },
        onDragEnter: () => setIsHovering(true),
        onDragLeave: () => setIsHovering(false),
    });
    return <div ref={dropRef} style={{ minHeight: '100%' }} >
        {
            list?.map(item => {
                return <div key={item.appComponentId} className={`${styles.comp} ${state.compAc === item.componentType ? styles.ac : ""}`} onClick={() => { dispatch({ type: "setAll", params: { compAc: item.componentType } }) }}>
                    <Banners data={item.configs} />
                </div>
            })
        }

    </div>
};
// 定义组件的 Props 类型
interface Props {
}
const Content = forwardRef((props: Props, ref) => {
    const { state, dispatch } = useModel("appPageConifg")
     // 使用 useImperativeHandle 暴露方法给父组件
    useImperativeHandle(ref, () => ({
    }));
    return <div className={styles.phone}>
        <div className={styles.content} >
            {/* 头部男女tabs */}
            <Space className={styles.tabs} size={[20, 20]}>
                {
                    ["男生", "女生"].map((s, i) => {
                        return <strong
                            key={i}
                            className={`${styles.tabs_text} ${state?.tabs === i ? styles.tabs_ac : ""}`}
                            onClick={() => {
                                dispatch({ type: "setAll", params: { tabs: i, compAc: 0 } })
                            }}
                        >
                            {s}
                        </strong>
                    })
                }

            </Space>
            {/* 内容 */}
            <DragItem />
        </div>
    </div>
})
export default Content;